@@ -333,7 +333,7 @@ def parse_arguments(*unparsed_arguments):
         '--repository',
         help='Path of repository to use, defaults to the configured repository if there is only one',
     )
-    mount_group.add_argument('--archive', help='Name of archive to mount', required=True)
+    mount_group.add_argument('--archive', help='Name of archive to mount')
     mount_group.add_argument(
         '--mount-point',
         metavar='PATH',
@@ -419,6 +419,13 @@ def parse_arguments(*unparsed_arguments):
         help='Path of repository to list, defaults to the configured repository if there is only one',
     )
     list_group.add_argument('--archive', help='Name of archive to list')
+    list_group.add_argument(
+        '--path',
+        metavar='PATH',
+        nargs='+',
+        dest='paths',
+        help='Paths to list from archive, defaults to the entire archive',
+    )
     list_group.add_argument(
         '--short', default=False, action='store_true', help='Output only archive or path names'
     )
